@@ -1,13 +1,15 @@
 """ Test imageio core functionality.
 """
 
-import time
-import sys
 import os
+import sys
+import time
 import shutil
+import random
+import tempfile
 import ctypes.util
-from zipfile import ZipFile
 from io import BytesIO
+from zipfile import ZipFile
 
 import numpy as np
 import pytest
@@ -22,8 +24,6 @@ from imageio import core
 from imageio.core import Request
 from imageio.core import get_remote_file, IS_PYPY
 
-if sys.version_info < (3,):
-    FileNotFoundError = OSError
 
 try:
     from pathlib import Path
@@ -202,6 +202,17 @@ def test_request():
     assert R._filename_zip[0] == get_remote_file("images/chelsea.zip")
     assert R.filename == get_remote_file("images/chelsea.zip") + "/chelsea.png"
 
+    # Test zip false-positive detection
+    with tempfile.TemporaryDirectory() as tmp_path:
+        bait_zip = os.path.join(tmp_path, "test.zip")
+        os.mkdir(bait_zip)
+        file_path = os.path.join(bait_zip, "foo.jpg")
+        chelsia = get_remote_file("images/chelsea.png")
+        shutil.copy(chelsia, file_path)
+
+        R = Request(file_path, "ri")
+        assert R._uri_type == core.request.URI_FILENAME
+
 
 def test_request_read_sources():
 
@@ -296,6 +307,60 @@ def test_request_save_sources():
         assert res == bytes
 
 
+def test_request_seekable_file_object():
+    SeekableFileObject = imageio.core.request.SeekableFileObject
+    data = bytes([int(random.uniform(0, 255)) for i in range(100)])
+    f1 = BytesIO(data)
+    f2 = SeekableFileObject(f1)
+
+    # Test all kinds of seeks, reads and tells
+    resses = []
+    for f in (f1, f2):
+        (f1.seek(0), f2.seek(0))
+        res = [
+            f.read(8),
+            f.tell(),
+            f.seek(0),
+            f.tell(),
+            f.read(8),
+            f.read(),
+            f.seek(20, 1),
+            f.read(8),
+            f.seek(10, 2),
+            f.read(8),
+            f.seek(-10, 2),
+            f.read(8),
+            f.seek(-20, 2),
+            f.tell(),
+            f.read(8),
+            f.read(0),
+            f.read(-1),
+        ]
+        resses.append(res)
+    assert resses[0] == resses[1]
+
+    # Test out of bounds
+    for f in (f1, f2):
+        # Align them
+        (f1.seek(0), f2.seek(0))
+        f.seek(3)
+        assert f.tell() == 3
+        with raises(ValueError):
+            f.seek(-10)
+        assert f.tell() == 3
+        f.seek(-10, 1)  # no raise!
+        assert f.tell() == 0
+        f.seek(-10, 2)
+        assert f.tell() == 90
+        f.seek(10, 2)
+        assert f.tell() == 110
+        assert f.read(1) == b""
+        f.seek(20, 1)
+        assert f.tell() == 130
+        f.seek(150)
+        assert f.tell() == 150
+
+
 def test_request_file_no_seek():
     class File:
         def read(self, n):
